PCB Environment: math Namespace Reference

PCB Environment 2

Loading...
Searching...
No Matches
Namespaces | Data Structures | Functions
math Namespace Reference

## Namespaces
namespace | approx

## Data Structures
class | Mat4
struct | Moments

## Functions
constexpr Real | Radians (Real D)
template<typename T>
T | squared (T v)
template<typename T>
T | reduce_max (const std::vector< T > &V)
template<typename T>
void | multiply (std::vector< T > &V, T s)

## Function Documentation

## ◆ multiply()

template<typename T>

void math::multiply | ( | std::vector< T > & | V,
|  | T | s )

## ◆ Radians()

Real math::Radians | ( | Real | D | ) |
| inlineconstexpr

## ◆ reduce_max()

template<typename T>

T math::reduce_max | ( | const std::vector< T > & | V | ) |

## ◆ squared()

template<typename T>

T math::squared | ( | T | v | ) |
| inline